@@ -1,45 +1,47 @@
 /*
-SPDX-FileCopyrightText: 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
-SPDX-FileCopyrightText: 2007 Kevin Kofler <kevin.kofler@chello.at>
+    SPDX-FileCopyrightText: 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+    SPDX-FileCopyrightText: 2007 Kevin Kofler <kevin.kofler@chello.at>
 
-SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "diffsettings.h"
 
+// KF
 #include <KConfig>
 #include <KConfigGroup>
-
+// Qt
 #include <QWidget>
 
-DiffSettings::DiffSettings(QWidget* parent)
-    : SettingsBase(parent),
-      m_linesOfContext(0),
-      m_format(Kompare::Unified),
-      m_largeFiles(false),
-      m_ignoreWhiteSpace(false),
-      m_ignoreAllWhiteSpace(false),
-      m_ignoreEmptyLines(false),
-      m_ignoreChangesDueToTabExpansion(false),
-      m_createSmallerDiff(false),
-      m_ignoreChangesInCase(false),
-      m_showCFunctionChange(false),
-      m_convertTabsToSpaces(false),
-      m_ignoreRegExp(false),
-      m_recursive(false),
-      m_newFiles(false),
-      m_excludeFilePattern(false),
-      m_excludeFilesFile(false)
+namespace KompareDiff2
+{
+
+DiffSettings::DiffSettings()
+    : m_linesOfContext(0)
+    , m_format(Unified)
+    , m_largeFiles(false)
+    , m_ignoreWhiteSpace(false)
+    , m_ignoreAllWhiteSpace(false)
+    , m_ignoreEmptyLines(false)
+    , m_ignoreChangesDueToTabExpansion(false)
+    , m_createSmallerDiff(false)
+    , m_ignoreChangesInCase(false)
+    , m_showCFunctionChange(false)
+    , m_convertTabsToSpaces(false)
+    , m_ignoreRegExp(false)
+    , m_recursive(false)
+    , m_newFiles(false)
+    , m_excludeFilePattern(false)
+    , m_excludeFilesFile(false)
 {
 }
 
-DiffSettings::~DiffSettings()
-{
-}
+DiffSettings::~DiffSettings() = default;
 
-void DiffSettings::loadSettings(KConfig* config)
+void DiffSettings::loadSettings(KConfig *config)
 {
     KConfigGroup group(config, QStringLiteral("Diff Options"));
+    // clang-format off
     m_diffProgram                    = group.readEntry("DiffProgram", QString());
     m_linesOfContext                 = group.readEntry("LinesOfContext", 3);
     m_largeFiles                     = group.readEntry("LargeFiles", true);
@@ -56,20 +58,24 @@ void DiffSettings::loadSettings(KConfig* config)
     m_showCFunctionChange            = group.readEntry("ShowCFunctionChange", false);
     m_recursive                      = group.readEntry("CompareRecursively", true);
     m_newFiles                       = group.readEntry("NewFiles", true);
+    // clang-format on
 
-    m_format = static_cast<Kompare::Format>(group.readEntry("Format", (int) Kompare::Unified));
+    m_format = static_cast<Format>(group.readEntry("Format", static_cast<int>(Unified)));
 
     KConfigGroup group2(config, QStringLiteral("Exclude File Options"));
-    m_excludeFilePattern             = group2.readEntry("Pattern", false);
-    m_excludeFilePatternList         = group2.readEntry("PatternList", QStringList());
-    m_excludeFilesFile               = group2.readEntry("File", false);
-    m_excludeFilesFileURL            = group2.readEntry("FileURL", QString());
-    m_excludeFilesFileHistoryList    = group2.readEntry("FileHistoryList", QStringList());
+    // clang-format off
+    m_excludeFilePattern          = group2.readEntry("Pattern", false);
+    m_excludeFilePatternList      = group2.readEntry("PatternList", QStringList());
+    m_excludeFilesFile            = group2.readEntry("File", false);
+    m_excludeFilesFileURL         = group2.readEntry("FileURL", QString());
+    m_excludeFilesFileHistoryList = group2.readEntry("FileHistoryList", QStringList());
+    // clang-format on
 }
 
-void DiffSettings::saveSettings(KConfig* config)
+void DiffSettings::saveSettings(KConfig *config)
 {
     KConfigGroup group(config, QStringLiteral("Diff Options"));
+    // clang-format off
     group.writeEntry("DiffProgram",                    m_diffProgram);
     group.writeEntry("LinesOfContext",                 m_linesOfContext);
     group.writeEntry("Format",                         (int)m_format);
@@ -87,15 +93,18 @@ void DiffSettings::saveSettings(KConfig* config)
     group.writeEntry("ShowCFunctionChange",            m_showCFunctionChange);
     group.writeEntry("CompareRecursively",             m_recursive);
     group.writeEntry("NewFiles",                       m_newFiles);
+    // clang-format on
 
     KConfigGroup group2(config, QStringLiteral("Exclude File Options"));
-    group2.writeEntry("Pattern",            m_excludeFilePattern);
-    group2.writeEntry("PatternList",        m_excludeFilePatternList);
-    group2.writeEntry("File",               m_excludeFilesFile);
-    group2.writeEntry("FileURL",            m_excludeFilesFileURL);
-    group2.writeEntry("FileHistoryList",    m_excludeFilesFileHistoryList);
+    // clang-format off
+    group2.writeEntry("Pattern",         m_excludeFilePattern);
+    group2.writeEntry("PatternList",     m_excludeFilePatternList);
+    group2.writeEntry("File",            m_excludeFilesFile);
+    group2.writeEntry("FileURL",         m_excludeFilesFileURL);
+    group2.writeEntry("FileHistoryList", m_excludeFilesFileHistoryList);
+    // clang-format on
 
     config->sync();
 }
 
-#include "moc_diffsettings.cpp"
+}
