@@ -1,15 +1,16 @@
 /*
-SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
 
-SPDX-License-Identifier: LGPL-2.0-or-later
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INTERACTIVEDIFFTEST_H
 #define INTERACTIVEDIFFTEST_H
 
-#include <QObject>
-
+// lib
 #include "difference.h"
+// Qt
+#include <QObject>
 
 class InteractiveDiffTest : public QObject
 {
@@ -28,8 +29,9 @@ private Q_SLOTS:
     void testApplyUnapply();
     void testContextDiff();
     void testNormalDiff();
+
 private:
-    void CompareDifferenceStringList(const Diff2::DifferenceStringList& actual, const QStringList& expected);
+    void CompareDifferenceStringList(const KompareDiff2::DifferenceStringList &actual, const QStringList &expected);
 };
 
 #endif //  INTERACTIVEDIFFTEST_H
